# Task Scheduling

Scheduling functions for tasks. They can be imported from `fluid.scheduler`:


```python
from fluid.scheduler import every, crontab
```

::: fluid.scheduler.Scheduler

::: fluid.scheduler.every

::: fluid.scheduler.crontab
